calculate_indep_category_order: Calculate independent variable ordering based on a specific...

View source: R/sorting_utils.R

calculate_indep_category_orderR Documentation

Calculate independent variable ordering based on a specific category value

Description

Calculate independent variable ordering based on a specific category value

Usage

calculate_indep_category_order(
  data,
  category_value,
  indep_col,
  descend_indep = FALSE
)

Arguments

data

Dataset with independent variable columns

category_value

The category value to sort by (e.g., "Not at all")

indep_col

Name of the independent variable column

descend_indep

Logical indicating if sorting should be descending

Value

Numeric vector of ordering values


saros documentation built on Nov. 10, 2025, 5:06 p.m.