calculate_indep_sum_value_order: Calculate independent variable ordering based on multiple...

View source: R/sorting_utils.R

calculate_indep_sum_value_orderR Documentation

Calculate independent variable ordering based on multiple category values

Description

Calculate independent variable ordering based on multiple category values

Usage

calculate_indep_sum_value_order(
  data,
  category_values,
  indep_col,
  descend_indep = FALSE
)

Arguments

data

Dataset

category_values

Vector of category values to sum

indep_col

Name of the independent variable column

descend_indep

Logical indicating if sorting should be descending

Value

Numeric vector of ordering values


saros documentation built on Nov. 10, 2025, 5:06 p.m.