Skip to contents

Simulates text wrapping and counts the maximum number of lines any label wraps to, giving exact line counts instead of estimates.

Usage

count_max_wrapped_lines(labels, width)

Arguments

labels

Character vector of labels

width

Maximum width for wrapping

Value

Integer, maximum number of wrapped lines