View source: R/makeme_helpers.R
| detect_variable_types | R Documentation |
Internal helper function that examines the class of variables in the subset data to determine their types (factor, numeric, character, etc.).
detect_variable_types(subset_data, dep_crwd, indep_crwd)
subset_data |
Data frame subset containing the relevant variables |
dep_crwd |
Character vector of dependent variable names for current crowd |
indep_crwd |
Character vector of independent variable names for current crowd |
List with two elements:
dep: Character vector of classes for dependent variables
indep: Character vector of classes for independent variables (empty if none)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.