Possibly using colour_palette_nominal if available. If not sufficient, uses a set palette from RColorBrewer.
get_colour_palette(
data,
col_pos,
colour_palette_nominal = NULL,
colour_palette_ordinal = NULL,
colour_na = NULL,
categories_treated_as_na = NULL,
call = rlang::caller_env()
)A colour set as character vector, where NA has the colour_na, and the rest are taken from colour_palette_nominal if available.
Your data.frame/tibble or srvyr-object (experimental)
data.frame // required
The data to be used for plotting.
Character vector of column names for which colours will be found.
User specified colour set
vector<character> // default: NULL (optional)
User-supplied default palette, excluding colour_na.
Colour for NA category
scalar<character> // default: NULL (optional)
Colour as a single string for NA values, if showNA is "ifany" or "always".
NA categories
vector<character> // default: NULL (optional)
Categories that should be treated as NA.
Internal call
obj:<call> // Default: rlang::caller_env() (optional)
Both the absolute and relative folderpaths are required, as strings.