| get_dep_display_column | R Documentation |
Checks if the number of dep variables matches the number of labels to determine whether to use .variable_label or .variable_name for display.
get_dep_display_column(dep_count, dep_labels)
dep_count |
Number of dependent variables |
dep_labels |
Vector of dependency labels |
Character string indicating which column to use
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.