Obtain range of N for a given data set and other settings.
n_rng(
data,
dep,
indep = NULL,
crowd = "all",
mesos_var = NULL,
mesos_group = NULL,
glue_template_1 = "{n}",
glue_template_2 = "[{n[1]}-{n[2]}]"
)Always a string.
Dataset
Character vector, names of (in)dependent variables
String, one of "all", "target" or "others".
Optional, NULL or string specifying name of variable used to split dataset.
Optional, NULL or string specifying value in mesos_var
indicating the target group.
String, for the case of a single value (1) or a range with minimum-maximum of values (2).