normalize_makeme_arguments: Normalize Multi-Choice Arguments to Single Values

View source: R/makeme_helpers.R

normalize_makeme_argumentsR Documentation

Normalize Multi-Choice Arguments to Single Values

Description

Internal helper function that ensures makeme arguments that might be vectors are normalized to single values by taking the first element.

Usage

normalize_makeme_arguments(args)

Arguments

args

List of makeme function arguments

Value

Modified args list with normalized single-value arguments:

  • showNA: First element of showNA vector

  • data_label: First element of data_label vector

  • data_label_position: First element of data_label_position vector

  • type: First element of evaluated type expression


saros documentation built on Nov. 10, 2025, 5:06 p.m.