View source: R/post_process_sarosplot_data.R
| process_indep_factor_levels | R Documentation |
Reverses factor levels for independent variables, but only for unordered factors. Preserves the natural ordering of ordered factors.
process_indep_factor_levels(data, indep = NULL)
data |
Data frame containing the data |
indep |
Character string naming the independent variable (or NULL) |
Modified data frame with reversed factor levels for unordered factors
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.