| tabular_read | R Documentation |
A wrapper function to read data from different file formats
tabular_read(path, format, ...)
path |
Character string specifying the file path |
format |
Character string specifying the format: "delim", "xlsx", "csv", "csv2", "tsv", "sav", "dta" |
... |
Additional arguments passed to the underlying read functions |
A data frame containing the loaded data
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.