View source: R/make_content.int_plot_html.R
| apply_label_wrapping | R Documentation |
Helper function to consistently wrap variable labels based on whether they appear on facet strips or x-axis, and whether inverse layout is used.
apply_label_wrapping(
data,
indep_length,
inverse,
strip_width,
x_axis_label_width
)
data |
Data frame containing .variable_label column |
indep_length |
Number of independent variables (0 or 1) |
inverse |
Logical, whether inverse layout is used |
strip_width |
Width for facet strip labels |
x_axis_label_width |
Width for x-axis labels |
Data frame with wrapped .variable_label column
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.