Count maximum wrapped lines for a character vector
Source:R/fig_height_h_barchart.R
count_max_wrapped_lines.RdSimulates text wrapping and counts the maximum number of lines any label wraps to, giving exact line counts instead of estimates.
R/fig_height_h_barchart.R
count_max_wrapped_lines.RdSimulates text wrapping and counts the maximum number of lines any label wraps to, giving exact line counts instead of estimates.