Taking an object from makeme(), this function estimates the height of a
figure for a horizontal bar chart.
fig_height_h_barchart2(
ggobj,
main_font_size = 7,
strip_angle = 0,
freq = FALSE,
x_axis_label_width = 20,
strip_width = 20,
legend_location = c("plot", "panel"),
n_legend_lines = NULL,
showNA = c("ifany", "never", "always"),
legend_key_chars_equivalence = 5,
multiplier_per_horizontal_line = NULL,
multiplier_per_vertical_letter = 1,
multiplier_per_facet = 1,
multiplier_per_legend_line = 1,
fixed_constant = 0,
figure_width_in_cm = 14,
margin_in_cm = 0,
max = 8,
min = 1
)Numeric value representing the estimated height of the figure.
ggplot2-object
Numeric. Font size for the main text.
Integer. Angle of the strip text.
Logical. If TRUE, frequency plot with categories next to each other. If FALSE (default), proportion plot with stacked categories.
Numeric. Width allocated for x-axis labels and strip labels respectively.
Character. Location of the legend. "plot" (default) or "panel".
Integer. Number of lines in the legend.
String, one of "ifany", "always" or "never". Not yet in use.
Integer. Approximate number of characters the legend key equals.
Numeric. Multiplier per horizontal line.
Numeric. Multiplier per vertical letter.
Numeric. Multiplier per facet height.
Numeric. Multiplier per legend line.
Numeric. Fixed constant to be added to the height.
Numeric. Width of the figure in centimeters.
Numeric. Margin in centimeters.
Numeric. Maximum height.
Numeric. Minimum height.
fig_height_h_barchart2(makeme(data = ex_survey, dep = b_1:b_2, indep = x1_sex))
Run the code above in your browser using DataLab