get_raw_labels: Helper function to extract raw variable labels from the data
Description
Helper function to extract raw variable labels from the data
Usage
get_raw_labels(data, col_pos = NULL, return_as_list = FALSE)
Value
List or character vector
Arguments
- data
Dataset
- col_pos
Optional, character vector of column names or integer vector of positions
- return_as_list
Flag, whether to return as list or character vector