Internal helper function that processes the kept and omitted column information for crowd-based filtering and applies global hiding logic.
handle_crowd_columns(
args,
kept_cols_list,
omitted_cols_list,
kept_indep_cats_list
)List containing processed crowd column information with global hiding logic applied based on hide_for_all_crowds_if_hidden_for_crowd settings
List of makeme function arguments
Named list of kept column information for each crowd
Named list of omitted variables for each crowd