View source: R/makeme_helpers.R
| normalize_makeme_arguments | R Documentation |
Internal helper function that ensures makeme arguments that might be vectors are normalized to single values by taking the first element.
normalize_makeme_arguments(args)
args |
List of makeme function arguments |
Modified args list with normalized single-value arguments:
showNA: First element of showNA vector
data_label: First element of data_label vector
data_label_position: First element of data_label_position vector
type: First element of evaluated type expression
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.