View source: R/makeme_helpers.R
| rename_crowd_outputs | R Documentation |
Internal helper function that renames crowd identifiers in the output based on provided translations.
rename_crowd_outputs(out, translations)
out |
Named list of crowd outputs |
translations |
Named list of translation mappings for crowd identifiers |
Modified out list with crowd names translated:
Names changed according to translations with crowd prefix pattern
Only string translations are applied
Untranslated crowds retain original names
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.