View source: R/makeme_helpers.R
| reorder_crowd_array | R Documentation |
Internal helper function that reorders the crowd array to prioritize crowds specified in hide_for_all_crowds_if_hidden_for_crowd, ensuring they are processed first to determine variable exclusions early.
reorder_crowd_array(crowd, hide_for_all_crowds_if_hidden_for_crowd)
crowd |
Character vector of crowd identifiers |
|
Character vector of crowd identifiers that should be processed first to determine global exclusions |
Character vector with reordered crowd identifiers:
Priority crowds first (those in hide_for_all_crowds_if_hidden_for_crowd)
Remaining crowds after
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.