| strip_wrap_var | R Documentation |
A utility function that applies string wrapping to both character and factor variables, preserving factor structure while wrapping the labels.
strip_wrap_var(x, width = Inf)
x |
Variable to wrap (character or factor) |
width |
Maximum width for wrapping |
Modified variable with wrapped text
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.